@@ -1,4 +1,4 @@
-# --------------------------------------------------------------- Imports ---------------------------------------------------------------- #
+# ------------------------------------------------------------ Imports ----------------------------------------------------------- #
 
 # System
 from typing import Optional, List, Dict, Union
@@ -9,15 +9,15 @@ from .product_image_set import ProductImageSet
 from .product_video import ProductVideo
 from .product_detail import ProductDetail
 
-# ---------------------------------------------------------------------------------------------------------------------------------------- #
+# -------------------------------------------------------------------------------------------------------------------------------- #
 
 
 
-# ------------------------------------------------------------ class: Product ------------------------------------------------------------ #
+# -------------------------------------------------------- class: Product -------------------------------------------------------- #
 
 class Product(BaseProduct):
 
-    # ------------------------------------------------------------- Init ------------------------------------------------------------- #
+    # --------------------------------------------------------- Init --------------------------------------------------------- #
 
     def __init__(
         self,
@@ -55,7 +55,7 @@ class Product(BaseProduct):
                         if image_url not in image_urls:
                             image_urls.append(image_url)
 
-                            if assoc_asin == asin and not main_image_url:
+                            if not main_image_url and (assoc_asin == asin or asin not in images.keys()):
                                 main_image_url = image_url
 
         super().__init__(title, asin, price, main_image_url)
@@ -82,4 +82,4 @@ class Product(BaseProduct):
                     self.video_urls.append(video['url'])
 
 
-# ---------------------------------------------------------------------------------------------------------------------------------------- #
\ No newline at end of file
+# -------------------------------------------------------------------------------------------------------------------------------- #
\ No newline at end of file
